#
# spec file for package apache-commons-cli
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name       cli
%global short_name      commons-%{base_name}
Name:           apache-commons-cli
Version:        1.5.0
Release:        2.2
Summary:        Command Line Interface Library for Java
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://commons.apache.org/%{base_name}/
Source0:        https://dlcdn.apache.org/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Source1:        %{name}-build.xml
Source2:        apache-commons-cli-rpmlintrc
Patch0:         CLI-253-workaround.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local
Provides:       jakarta-%{short_name} = %{version}-%{release}
Obsoletes:      jakarta-%{short_name} < %{version}-%{release}
Provides:       apache-cli = %{version}-%{release}
Obsoletes:      apache-cli < %{version}-%{release}
BuildArch:      noarch

%description
The CLI library provides an API for working with the
command line arguments and options.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML
Provides:       jakarta-%{short_name}-javadoc = %{version}-%{release}
Obsoletes:      jakarta-%{short_name}-javadoc < %{version}-%{release}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{short_name}-%{version}-src
cp %{SOURCE1} build.xml
%patch0 -p1

%pom_remove_parent

%build
%ant package javadoc

%install
# jars
install -Dpm 644 target/%{short_name}-%{version}.jar %{buildroot}%{_javadir}/%{short_name}.jar
ln -sf %{short_name}.jar %{buildroot}%{_javadir}/%{name}.jar

# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -pm 644 pom.xml %{buildroot}%{_mavenpomdir}/%{short_name}.pom
%add_maven_depmap %{short_name}.pom %{short_name}.jar -a "org.apache.commons:%{short_name}"

# javadoc
install -d -m 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/api*/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files -f .mfiles
%license LICENSE.txt NOTICE.txt
%doc README.md RELEASE-NOTES.txt
%{_javadir}/%{name}.jar

%files javadoc
%license LICENSE.txt
%{_javadocdir}/%{name}

%changelog
* Thu Sep 21 2023 Fridrich Strba <fstrba@suse.com>
- Build with java source/target levels 8
* Thu Dec 16 2021 David Anes <david.anes@suse.com>
- Rebased patch CLI-253-workaround.patch to new version.
- Updated build XML file to new version.
- Harmonized the use of X.Y.X strings everywhere.
- Updated new source locations from Apache.
- Added 'apache-commons-cli-rpmlintrc' to silence 'package-with-huge-docs' warning (Javadoc generates many files...)
- Update to 1.5:
  * New features:
  - (CLI-217) Accommodate toggling partial matching in DefaultParser. Thanks to Rubin Simons.
  - (CLI-274) Option parser type EXISTING_FILE_VALUE not check file existing Thanks to Béla Schaum.
  - (CLI-271) CommandLine.getXXX and CommandLine.hasXXX should accept an Option as a parameter Thanks to Christoph Läubrich.
  - (CLI-276) Adjust access-modifier of checkRequiredOptions() to protected. Thanks to Jason Dillon.
  - (CLI-282) TypeHandler should throw ParseException for an unsupported class. Thanks to Alex Nordlund.
  - Added setter for Builder.option #33. Thanks to Waldemar Sojka, Gary Gregory.
  - Add Option unit tests #76. Thanks to Waldemar Sojka, Gary Gregory.
  * Fixed bugs:
  - Fix NPE in DefaultParser.isLongOption(String). Thanks to Gary Gregory.
  - (CLI-279) @param or @return lines should end with a period in CommandLine.java Thanks to Krishna Mohan Rao Kandunoori.
  - Replace deprecated FindBugs with SpotBugs. Thanks to Gary Gregory.
  - Replace CLIRR with JApiCmp. Thanks to Gary Gregory.
  - Option Javadocs grammar nits #55. Thanks to Elliotte Rusty Harold.
  - Minor Improvements #57, #61. Thanks to Arturo Bernal, Gary Gregory.
  - (CLI-254) Input "test" gets parsed as test, quotes die #58. Thanks to stoty.
  - (CLI-287) Allow whitespace-only header and footer #26. Thanks to MrQubo, Gary Gregory.
  * Updates:
  - (CLI-294) Update Java from version 5 to 7.
  - Docs: Replace OptionBuilder in usage page #30. Thanks to Mincong Huang.
  - Remove deprecated sudo setting. #36. Thanks to dengliming.
  - Bump junit:junit from 4.12 to 4.13.2, #53, #60. Thanks to Gary Gregory, Dependabot.
  - Bump commons-parent from 48 to 52. Thanks to Dependabot.
  - Bump maven-pmd-plugin from 3.12.0 to 3.15.0, #44, #54, #67. Thanks to Dependabot.
  - Bump actions/checkout from v2.3.1 to v2.3.5 #46, #72. Thanks to Dependabot.
  - Bump actions/setup-java from v1.4.2 to v2 #50. Thanks to Dependabot, Gary Gregory.
  - Bump maven-antrun-plugin from 1.7 to 3.0.0 #43. Thanks to Dependabot.
  - Bump maven-checkstyle-plugin from 2.15 to 3.1.2 #41. Thanks to Gary Gregory.
  - Bump checkstyle to 9.0.1 #68. Thanks to Gary Gregory.
  - Bump actions/cache from 2 to 2.1.6 #64, #65. Thanks to Dependabot.
  - Bump commons.animal-sniffer.version 1.19 -> 1.20. Thanks to Gary Gregory.
  - Bump maven-bundle-plugin 5.1.1 -> 5.1.2. Thanks to Gary Gregory.
  - Bump biz.aQute.bndlib.version 5.1.2 -> 6.0.0. Thanks to Gary Gregory.
  - Bump spotbugs from 4.4.1 to 4.4.2 #70. Thanks to Dependabot.
  - Bump spotbugs-maven-plugin from 4.4.1 to 4.4.2.2 #71. Thanks to Dependabot.-
* Fri Feb 12 2021 Fridrich Strba <fstrba@suse.com>
- Add OSGi manifest to the build files.
- Set java source/target levels to 6
* Mon Mar 25 2019 Fridrich Strba <fstrba@suse.com>
- Remove pom parent, since we don't use it when not building with
  maven
* Tue Feb  5 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description; update RPM groups.
* Tue Feb  5 2019 Fridrich Strba <fstrba@suse.com>
- Clean-up the spec file
- Removed patch:
  * commons-cli-1.4-jdk9.patch
    + not needed since we are not building with maven
- Added patch:
  * CLI-253-workaround.patch
    + [CLI-253] Prevent "Unrecognized option: --null" when handling
  long opts in PosixParser
* Tue Oct 23 2018 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 1.4
- Modify the build.xml.tar.bz2 to build with source/target 8 and
  adapt for the commons-cli-1.4
- Modified patch:
  * commons-cli-1.2-jdk9.patch -> commons-cli-1.4-jdk9.patch
    + Rediff the remaining hunk to the changed context of pom.xml
* Tue May 15 2018 fstrba@suse.com
- Modified patch:
  * commons-cli-1.2-jdk9.patch
    + Build with source and target 8 to prepare for a possible
    removal of 1.6 compatibility
- Run fdupes on the documentation
* Fri Sep 29 2017 fstrba@suse.com
- Don't condition the maven defines on release version, but on
  _maven_repository being defined
* Thu Sep 14 2017 fstrba@suse.com
- Added patch:
  * commons-cli-1.2-jdk9.patch
  - Specify java source and target level 1.6 in order to allow
    building with jdk9
* Fri May 19 2017 tchvatal@suse.com
- Fix build with new javapackages-tools
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Thu Dec  4 2014 p.drouand@gmail.com
- Remove java-devel dependency; not needed anymore
* Fri Jun 27 2014 tchvatal@suse.com
- Fix the pom providing on 13.2
* Sat Mar  8 2014 badshah400@gmail.com
- For openSUSE >= 13.1 remove all references to maven scripts as
  these do not work; fixes building for openSUSE >= 13.1
- Lots of specfile formatting cleanups
- Move old %%changelog section entries to .changes with proper
  formatting
- Add copyright info to spec file.
* Mon Dec 12 2011 dmacvicar@suse.de
- rename apache-cli to apache-commons-cli
- add java() provides
* Tue Jul 19 2011 dmacvicar@suse.de
- converted to build with ant:ant
- removed reference to non existing target/osgi/MANIFEST
  in maven-build.xml
* Tue Nov  9 2010 chris.spike@arcor.de
- Removed maven* BRs in favour of apache-commons-parent
- Added deprecated groupId to depmap for compatibility reasons
* Mon Oct 18 2010 chris.spike@arcor.de
- Removed Epoch
* Sun Oct  3 2010 chris.spike@arcor.de
- Rename and rebase from jakarta-commons-cli
